/* 
Script para validar as Regras No Temporais - rea Judiciria - e_Gesto 2o grau.

Validao da regra do quadro 1.2(LITIGIOSIDADE):
Regra 3 - Vnculo com outros itens (Parte 2)


Desenvolvido por Lucas Aranha Barreto (lucas.barreto@trt1.jus.br)
STI - CGSP (Coordenadoria de Gesto de Sistemas e Portal)
TRT 1 Regio - RJ 

---------------------------------------------------------------------------------------------
Obs: Nesse script a tabela interna de processos do TRT1 (TB_PROCESSO)  referenciada. Essa 
tabela contm o atributo SQ_PROCESSO, que corresponde ao NUM_INTERNO_PROCESSO do e-Gesto. Uma
juno  feita nas tabelas TB_PROCESSO e EGT_INFO_PROCESSO atravs desses atributos 
(SQ_PROCESSO e NUM_INTERNO_PROCESSO) para o relatrio poder mostrar o nmero CNJ 
do processo (NR_PROCESSO_ATUAL da TB_PROCESSO). 

Sendo assim, o script tem que ser adaptado para funcionar na estrutura especfica do 
banco de dados de outro regional.
---------------------------------------------------------------------------------------------
*/

DECLARE
remessa NUMBER(10) := 20021; --<< PREENCHER: nmero da remessa a ser validada
lote NUMBER (2) := 1;        --<< PREENCHER: nmero do lote a ser validado
qSoma number(10) := 0;

begin
-----------------------------------------------------------------------------------------------
/* 1) A quantidade do item 2227 deve ser 0 e o Valor deve ser nulo 
      se o item 2.137 for igual a zero; */
  declare
  q2227 number(5) := 0;
  q2137 number(5) := 0; 
 
  begin
  select SUM(num_quantidade_item)
    into q2227
    from egt_info_item
   where num_item = 2227
     and num_remessa = remessa
     and num_lote = lote;
  
  select SUM(num_quantidade_item)
    into q2137
    from egt_info_item
   where num_item = 2137
     and num_remessa = remessa
     and num_lote = lote;
                  
     if (q2137 = 0 and q2227 <> 0) then
        dbms_output.put_line ('Violao do vnculo de quantidade do item 2227 (1)!' || CHR(10) || CHR(10) ||
                              'A quantidade do item 2227 no  0!' || CHR(10) || CHR(10));
     else
        dbms_output.put_line ('Vnculo de quantidade do item 2227 (1) validado!' || CHR(10) || CHR(10));
     end if;   
  end;

---------------------------------------------------------------------------------------------
/* 2) A quantidade do item 2227 deve ser maior que 0 e o Valor deve ser maior ou igual a 0 
     se o item 2.137 for maior que zero para as classes processuais consideradas nesse item.*/  
  declare
  q2227 number := 0;
  q2137 number := 0;
  
  begin
  select SUM(num_quantidade_item)
    into q2227
    from egt_info_item
   where num_item = 2227
     and num_remessa = remessa
     and num_lote = lote;
  
  select SUM(num_quantidade_item)
    into q2137
    from egt_info_item
   where num_item = 2137
     and num_remessa = remessa
     and num_lote = lote;
     
     if (q2137 <> 0 and q2227 = 0) then
        dbms_output.put_line ('Violao do vnculo de quantidade do item 2227 (2)!' || CHR(10) || CHR(10)||
                              'A quantidade do item 2227 deveria ser maior do que 0!' || CHR(10) || CHR(10) );
     else
        dbms_output.put_line ('Vnculo de quantidade do item 2227 (2) validado!' || CHR(10) || CHR(10) );
     end if;   
  end;
  
 ---------------------------------------------------------------------------------------------
/* 3) Os processos do detalhe do item 2227 devem ser os processos informados
      no item 2.137 para as classes processuais consideradas nesse item. */
  declare
  existe boolean := false;
  
  begin   
  dbms_output.put_line('Verificao do item 2227 (3).' || CHR(10) || CHR(10) || 
                       'Processos que esto no detalhe do item 2227 e no esto no detalhe do item 2137:' || CHR(10) || CHR(10));
  
  /* Cursor que identifica os processos que esto no detalhe do item 2227 e no esto no detalhe do item 2137 */
  FOR c2227 IN (select num_interno_processo, proc.nr_processo_atual
                  from egt_info_processo infp, sap.tb_processo proc
                 where infp.num_interno_processo = proc.sq_processo
                   and num_item = 2227 
                   and num_remessa = remessa 
                   and num_lote = lote)
           
           LOOP
           FOR c2137 IN (select num_interno_processo
                         from egt_info_processo
                         where num_item = 2137 and
                               num_remessa = remessa and
                               num_lote = lote)
                         
                         LOOP
                         if(c2227.num_interno_processo = c2137.num_interno_processo)
                         then
                             existe := true;
                             exit;
                         end if;                       
                         END LOOP;
                         
                         if(not existe)
                         then dbms_output.put_line(c2227.num_interno_processo || '    ' || c2227.nr_processo_atual);                  
                         end if;
                         existe := false;
           END LOOP;
           dbms_output.put_line(CHR(10) || '-----------------------------------------------------');          
  end;
  
---------------------------------------------------------------------------------------------
/* 3) Os processos do detalhe do item 2227 devem ser os processos informados
      no item 2.137 para as classes processuais consideradas nesse item. */
  declare
  existe boolean := false;
  
  begin  
  dbms_output.put_line('Verificao do item 2227 (3).' || CHR(10) || CHR(10) || 
                       'Processos que esto no detalhe do item 2137 e no esto no detalhe do item 2227:' || CHR(10) || CHR(10));
  
  /* Cursor que identifica os processos que esto no detalhe do item 2137 e no esto no detalhe do item 2227 */
  FOR c2137 IN (select num_interno_processo, proc.nr_processo_atual
     from egt_info_processo infp, sap.tb_processo proc
     where infp.num_interno_processo = proc.sq_processo
     and num_item = 2137 and
           num_remessa = remessa and
           num_lote = lote)
           
           LOOP
           FOR c2227 IN (select num_interno_processo
                         from egt_info_processo
                         where num_item = 2227 and
                               num_remessa = remessa and
                               num_lote = lote)
                         
                         LOOP
                         if(c2137.num_interno_processo = c2227.num_interno_processo)
                         then
                             existe := true;
                             exit;
                         end if;                       
                         END LOOP;
                         
                         if(not existe)
                         then dbms_output.put_line(c2137.num_interno_processo || '    ' || c2137.nr_processo_atual);                  
                         end if;
                         existe := false;
           END LOOP;
           dbms_output.put_line(CHR(10) || '-----------------------------------------------------');          
  end;  

--------------------------------------------------------------------------------------------- 
/* 1) A quantidade do item 2228 deve ser 0 e o Valor deve ser nulo 
      se o item 2.138 for igual a zero; */
  declare
  q2228 number(5) := 0;
  q2138 number(5) := 0; 
 
  begin
  select SUM(num_quantidade_item)
    into q2228
    from egt_info_item
   where num_item = 2228
     and num_remessa = remessa
     and num_lote = lote;
  
  select SUM(num_quantidade_item)
    into q2138
    from egt_info_item
   where num_item = 2138
     and num_remessa = remessa
     and num_lote = lote;
                  
     if (q2138 = 0 and q2228 <> 0) then
        dbms_output.put_line ('Violao do vnculo de quantidade do item 2228 (1)!' || CHR(10) || CHR(10) ||
                              'A quantidade do item 2228 no  0!' || CHR(10) || CHR(10));
     else
        dbms_output.put_line ('Vnculo de quantidade do item 2228 (1) validado!' || CHR(10) || CHR(10));
     end if;   
  end;

--------------------------------------------------------------------------------------------- 
/* 2) A quantidade do item 2228 deve ser maior que 0 e o Valor deve ser maior ou igual a 0 
      se o item 2.138 for maior que zero para as classes processuais consideradas nesse item; */  
  declare
  q2228 number := 0;
  q2138 number := 0;
  
  begin
  select SUM(num_quantidade_item)
    into q2228
    from egt_info_item
   where num_item = 2228
     and num_remessa = remessa
     and num_lote = lote;
  
  select SUM(num_quantidade_item)
    into q2138
    from egt_info_item
   where num_item = 2138
     and num_remessa = remessa
     and num_lote = lote;
     
     if (q2138 <> 0 and q2228 = 0) then
        dbms_output.put_line ('Violao do vnculo de quantidade do item 2228 (2)!' || CHR(10) || CHR(10)||
                              'A quantidade do item 2228 deveria ser maior do que 0!' || CHR(10) || CHR(10) );
     else
        dbms_output.put_line ('Vnculo de quantidade do item 2228 (2) validado!' || CHR(10) || CHR(10) );
     end if;   
  end;
  
  --------------------------------------------------------------------------------------------- 
/* 3) Os processos do detalhe do item 2228 devem ser os processos informados
      no item 2.138 para as classes processuais consideradas nesse item. */
  declare
  existe boolean := false;
  
  begin
  dbms_output.put_line('Verificao do item 2228 (3).' || CHR(10) || CHR(10) || 
                       'Processos que esto no detalhe do item 2228 e no esto no detalhe do item 2138:' || CHR(10) || CHR(10));
  
  /* Cursor que identifica os processos que esto no detalhe do item 2228 e no esto no detalhe do item 2138 */
  FOR c2228 IN (select num_interno_processo, proc.nr_processo_atual
     from egt_info_processo infp, sap.tb_processo proc
     where infp.num_interno_processo = proc.sq_processo
     and num_item = 2228 and
           num_remessa = remessa and
           num_lote = lote)
           
           LOOP
           FOR c2138 IN (select num_interno_processo
                         from egt_info_processo
                         where num_item = 2138 and
                               num_remessa = remessa and
                               num_lote = lote)
                         
                         LOOP
                         if(c2228.num_interno_processo = c2138.num_interno_processo)
                         then
                             existe := true;
                             exit;
                         end if;                       
                         END LOOP;
                         
                         if(not existe)
                         then dbms_output.put_line(c2228.num_interno_processo || '    ' || c2228.nr_processo_atual);                  
                         end if;
                         existe := false;
           END LOOP;
           dbms_output.put_line(CHR(10) || '-----------------------------------------------------');         
  end;
  
  --------------------------------------------------------------------------------------------- 
/* 3) Os processos do detalhe do item 2228 devem ser os processos informados
      no item 2.138 para as classes processuais consideradas nesse item. */
  declare
  existe boolean := false;
  
  begin  
  dbms_output.put_line('Verificao do item 2227 (3).' || CHR(10) || CHR(10) || 
                       'Processos que esto no detalhe do item 2138 e no esto no detalhe do item 2228:' || CHR(10) || CHR(10));
  
  /* Cursor que identifica os processos que esto no detalhe do item 2137 e no esto no detalhe do item 2227 */
  FOR c2138 IN (select num_interno_processo, proc.nr_processo_atual
     from egt_info_processo infp, sap.tb_processo proc
     where infp.num_interno_processo = proc.sq_processo
     and num_item = 2138 and
           num_remessa = remessa and
           num_lote = lote)
           
           LOOP
           FOR c2228 IN (select num_interno_processo
                         from egt_info_processo
                         where num_item = 2228 and
                               num_remessa = remessa and
                               num_lote = lote)
                         
                         LOOP
                         if(c2138.num_interno_processo = c2228.num_interno_processo)
                         then
                             existe := true;
                             exit;
                         end if;                       
                         END LOOP;
                         
                         if(not existe)
                         then dbms_output.put_line(c2138.num_interno_processo || '    ' || c2138.nr_processo_atual);                  
                         end if;
                         existe := false;
           END LOOP;
           dbms_output.put_line(CHR(10) || '-----------------------------------------------------');          
  end;    

--------------------------------------------------------------------------------
/* 1) A quantidade do item 2230 deve ser 0 e o Valor deve ser nulo 
      se os itens 2.150 e 2151 forem iguais a zero; */
  declare
  q2230 number(5) := 0; 
 
  begin
  select SUM(num_quantidade_item)
    into q2230
    from egt_info_item
   where num_item = 2230
     and num_remessa = remessa
     and num_lote = lote;
  
  select SUM(num_quantidade_item)
    into qSoma
    from egt_info_item
   where (num_item = 2150 or num_item = 2151)
     and num_remessa = remessa
     and num_lote = lote;
                  
     if (qSoma = 0 and q2230 <> 0) then
        dbms_output.put_line ('Violao do vnculo de quantidade do item 2230 (1)!' || CHR(10) || CHR(10) ||
                              'A quantidade do item 2230 no  0!' || CHR(10) || CHR(10));
     else
        dbms_output.put_line ('Vnculo de quantidade do item 2230 (1) validado!' || CHR(10) || CHR(10));
     end if;   
  end;

------------------------------------------------------------------------------------------
/* 2) Os processos do detalhe devem ser um subgrupo dos processos informados nos itens
      2.150 e 2.151 para as classes processuais consideradas no item 2.230 */
  declare
  existe boolean := false;
  
  begin  
  dbms_output.put_line('Verificao do item 2230 (2).' || CHR(10) || CHR(10) || 
                       'Processos que esto no detalhe do item 2230 e no esto no detalhe do item 2150 nem do 2151:' || CHR(10) || CHR(10));
  
  /* Cursor que identifica os processos que esto no detalhe do item 2230 e no esto no detalhe do item 2150 e 2151 */
  FOR c2230 IN (select num_interno_processo, proc.nr_processo_atual
     from egt_info_processo infp, sap.tb_processo proc
     where infp.num_interno_processo = proc.sq_processo
     and num_item = 2230 and
           num_remessa = remessa and
           num_lote = lote)
           
           LOOP
           FOR c2150_2151 IN (select num_interno_processo
                         from egt_info_processo
                         where (num_item = 2150 or num_item = 2151) and
                               num_remessa = remessa and
                               num_lote = lote)
                         
                         LOOP
                         if(c2230.num_interno_processo = c2150_2151.num_interno_processo)
                         then
                             existe := true;
                             exit;
                         end if;                       
                         END LOOP;
                         
                         if(not existe)
                         then dbms_output.put_line(c2230.num_interno_processo || '    ' || c2230.nr_processo_atual);                  
                         end if;
                         existe := false;
           END LOOP;
           dbms_output.put_line(CHR(10) ||  '-----------------------------------------------------');         
  end;

-----------------------------------------------------------------------------------  
/* 1) A quantidade do item 2232 deve ser 0 e o Valor deve ser nulo 
      se o item 2.174 for igual a zero; */
  declare
  q2232 number(5) := 0;
  q2174 number(5) := 0; 
 
  begin
  select SUM(num_quantidade_item)
    into q2232
    from egt_info_item
   where num_item = 2232
     and num_remessa = remessa
     and num_lote = lote;
  
  select SUM(num_quantidade_item)
    into q2174
    from egt_info_item
   where num_item = 2174
     and num_remessa = remessa
     and num_lote = lote;
                  
     if (q2174 = 0 and q2232 <> 0) then
        dbms_output.put_line ('Violao do vnculo de quantidade do item 2232 (1)!' || CHR(10) || CHR(10) ||
                              'A quantidade do item 2232 no  0!' || CHR(10) || CHR(10));
     else
        dbms_output.put_line ('Vnculo de quantidade do item 2232 (1) validado!' || CHR(10) || CHR(10));
     end if;   
  end;
  
-----------------------------------------------------------------------------------------------
/* 2) A quantidade do item 2232 deve ser maior que 0 e o Valor deve ser maior ou igual a 0
      se o item 2.174 for maior que zero para as classes processuais consideradas nesse item; */  
  declare
  q2232 number := 0;
  q2174 number := 0;
  
  begin 
  select SUM(num_quantidade_item)
    into q2232
    from egt_info_item
   where num_item = 2232
     and num_remessa = remessa
     and num_lote = lote;
  
  select SUM(num_quantidade_item)
    into q2174
    from egt_info_item
   where num_item = 2174
     and num_remessa = remessa
     and num_lote = lote;
     
     if (q2174 <> 0 and q2232 = 0) then
        dbms_output.put_line ('Violao do vnculo de quantidade do item 2232 (2)!' || CHR(10) || CHR(10)||
                              'A quantidade do item 2232 deveria ser maior do que 0!' || CHR(10) || CHR(10) );
     else
        dbms_output.put_line ('Vnculo de quantidade do item 2232 (2) validado!' || CHR(10) || CHR(10) );
     end if;   
     dbms_output.put_line(CHR(10) || '-----------------------------------------------------');
  end;
  
  ---------------------------------------------------------------------------------------
/* 3) Os processos do detalhe do item 2232 devem ser os processos informados
      no item 2.174 para as classes processuais consideradas nesse item. */
  declare
  existe boolean := false;
  
  begin  
  dbms_output.put_line('Verificao do item 2232 (3).' || CHR(10) || CHR(10) || 
                       'Processos que esto no detalhe do item 2232 e no esto no detalhe do item 2174:' || CHR(10) || CHR(10));
  
  /* Cursor que identifica os processos que esto no detalhe do item 2232 e no esto no detalhe do item 2174 */
  FOR c2232 IN (select num_interno_processo, proc.nr_processo_atual
     from egt_info_processo infp, sap.tb_processo proc
     where infp.num_interno_processo = proc.sq_processo
     and num_item = 2232 and
           num_remessa = remessa and
           num_lote = lote)
           
           LOOP
           FOR c2174 IN (select num_interno_processo
                         from egt_info_processo
                         where num_item = 2174 and
                               num_remessa = remessa and
                               num_lote = lote)
                         
                         LOOP
                         if(c2232.num_interno_processo = c2174.num_interno_processo)
                         then
                             existe := true;
                             exit;
                         end if;                       
                         END LOOP;
                         
                         if(not existe)
                         then dbms_output.put_line(c2232.num_interno_processo || '    ' || c2232.nr_processo_atual);                  
                         end if;
                         existe := false;
           END LOOP;
           dbms_output.put_line(CHR(10) ||  '-----------------------------------------------------');          
  end;
  
-------------------------------------------------------------------------------------------
/* 3) Os processos do detalhe do item 2232 devem ser os processos informados
      no item 2.174 para as classes processuais consideradas nesse item. */
  declare
  existe boolean := false;
  
  begin  
  dbms_output.put_line('Verificao do item 2232 (3).' || CHR(10) || CHR(10) || 
                       'Processos que esto no detalhe do item 2174 e no esto no detalhe do item 2232:' || CHR(10) || CHR(10));
  
  /* Cursor que identifica os processos que esto no detalhe do item 2174 e no esto no detalhe do item 2232 */
  FOR c2174 IN (select num_interno_processo, proc.nr_processo_atual
     from egt_info_processo infp, sap.tb_processo proc
     where infp.num_interno_processo = proc.sq_processo
     and num_item = 2174 and
           num_remessa = remessa and
           num_lote = lote)
           
           LOOP
           FOR c2232 IN (select num_interno_processo
                         from egt_info_processo
                         where num_item = 2232 and
                               num_remessa = remessa and
                               num_lote = lote)
                         
                         LOOP
                         if(c2174.num_interno_processo = c2232.num_interno_processo)
                         then
                             existe := true;
                             exit;
                         end if;                       
                         END LOOP;
                         
                         if(not existe)
                         then dbms_output.put_line(c2174.num_interno_processo || '    ' || c2174.nr_processo_atual);                  
                         end if;
                         existe := false;
           END LOOP;
           dbms_output.put_line(CHR(10) ||  '-----------------------------------------------------');          
  end;  
  
----------------------------------------------------------------------------------------
/* 1) A quantidade do item 2234 deve ser 0 e o Valor deve ser nulo 
      se o item 2.192 for igual a zero; */
  declare
  q2234 number(5) := 0;
  q2192 number(5) := 0; 
 
  begin
  select SUM(num_quantidade_item)
    into q2234
    from egt_info_item
   where num_item = 2234
     and num_remessa = remessa
     and num_lote = lote;
  
  select SUM(num_quantidade_item)
    into q2192
    from egt_info_item
   where num_item = 2192
     and num_remessa = remessa
     and num_lote = lote;
                  
     if (q2192 = 0 and q2234 <> 0) then
        dbms_output.put_line ('Violao do vnculo de quantidade do item 2234 (1)!' || CHR(10) || CHR(10) ||
                              'A quantidade do item 2234 no  0!' || CHR(10) || CHR(10));
     else
        dbms_output.put_line ('Vnculo de quantidade do item 2234 (1) validado!' || CHR(10) || CHR(10));
     end if;   
  end;
  
  ------------------------------------------------------------------------------------------
/* 2) A quantidade do item 2234 deve ser maior que 0 e o Valor deve ser maior ou igual a 0
      se o item 2.192 for maior que zero para as classes processuais consideradas nesse item; */  
  declare
  q2234 number := 0;
  q2192 number := 0;
  
  begin
  select SUM(num_quantidade_item)
    into q2234
    from egt_info_item
   where num_item = 2234
     and num_remessa = remessa
     and num_lote = lote;
  
  select SUM(num_quantidade_item)
    into q2192
    from egt_info_item
   where num_item = 2192
     and num_remessa = remessa
     and num_lote = lote;
     
     if (q2192 <> 0 and q2234 = 0) then
        dbms_output.put_line ('Violao do vnculo de quantidade do item 2234 (2)!' || CHR(10) || CHR(10)||
                              'A quantidade do item 2234 deveria ser maior do que 0!' || CHR(10) || CHR(10) );
     else
        dbms_output.put_line ('Vnculo de quantidade do item 2234 (2) validado!' || CHR(10) || CHR(10) );
     end if;   
  end;

  ------------------------------------------------------------------------------------------
/* 3) Os processos do detalhe do item 2234 devem ser os processos informados
      no item 2.192 para as classes processuais consideradas nesse item. */
  declare
  existe boolean := false;
  
  begin  
  dbms_output.put_line('Verificao do item 2234 (3).' || CHR(10) || CHR(10) || 
                       'Processos que esto no detalhe do item 2234 e no esto no detalhe do item 2192:' || CHR(10) || CHR(10));
  
  /* Cursor que identifica os processos que esto no detalhe do item 2234 e no esto no detalhe do item 2192 */
  FOR c2234 IN (select num_interno_processo, proc.nr_processo_atual
     from egt_info_processo infp, sap.tb_processo proc
     where infp.num_interno_processo = proc.sq_processo
     and num_item = 2234 and
           num_remessa = remessa and
           num_lote = lote)          
           LOOP
           FOR c2192 IN (select num_interno_processo
                         from egt_info_processo
                         where num_item = 2192 and
                               num_remessa = remessa and
                               num_lote = lote)
                                        
                         LOOP
                         if(c2234.num_interno_processo = c2192.num_interno_processo)
                         then
                             existe := true;
                             exit;
                         end if;                       
                         END LOOP;
                         
                         if(not existe)
                         then dbms_output.put_line(c2234.num_interno_processo || '    ' || c2234.nr_processo_atual);                  
                         end if;
                         existe := false;
           END LOOP;
           dbms_output.put_line(CHR(10) || '-----------------------------------------------------');          
  end;

  ------------------------------------------------------------------------------------------  
/* 3) Os processos do detalhe do item 2234 devem ser os processos informados
      no item 2.192 para as classes processuais consideradas nesse item. */
  declare
  existe boolean := false;
  
  begin  
  dbms_output.put_line('Verificao do item 2234 (3).' || CHR(10) || CHR(10) || 
                       'Processos que esto no detalhe do item 2192 e no esto no detalhe do item 2234:' || CHR(10) || CHR(10));
  
  /* Cursor que identifica os processos que esto no detalhe do item 2192 e no esto no detalhe do item 2234 */
  FOR c2192 IN (select num_interno_processo, proc.nr_processo_atual
     from egt_info_processo infp, sap.tb_processo proc
     where infp.num_interno_processo = proc.sq_processo
     and num_item = 2192 and
           num_remessa = remessa and
           num_lote = lote)
           
           LOOP
           FOR c2234 IN (select num_interno_processo
                         from egt_info_processo
                         where num_item = 2234 and
                               num_remessa = remessa and
                               num_lote = lote)
                                        
                         LOOP
                         if(c2192.num_interno_processo = c2234.num_interno_processo)
                         then
                             existe := true;
                             exit;
                         end if;                       
                         END LOOP;
                         
                         if(not existe)
                         then dbms_output.put_line(c2192.num_interno_processo || '    ' || c2192.nr_processo_atual);                  
                         end if;
                         existe := false;
           END LOOP;
           dbms_output.put_line(CHR(10) || '-----------------------------------------------------');          
  end;  
  
   ------------------------------------------------------------------------------------------
/* 1) A quantidade do item 2236 deve ser 0 e o Valor deve ser nulo 
      se os itens 2.192 e 2.195 forem iguais a zero; */
  declare
  q2236 number(5) := 0; 
 
  begin
  select SUM(num_quantidade_item)
    into q2236
    from egt_info_item
   where num_item = 2236
     and num_remessa = remessa
     and num_lote = lote;
  
  select SUM(num_quantidade_item)
    into qSoma
    from egt_info_item
   where (num_item = 2192 or num_item = 2195)
     and num_remessa = remessa
     and num_lote = lote;
                  
     if (qSoma = 0 and q2236 <> 0) then
        dbms_output.put_line ('Violao do vnculo de quantidade do item 2236 (1)!' || CHR(10) || CHR(10) ||
                              'A quantidade do item 2236 no  0!' || CHR(10) || CHR(10));
     else
        dbms_output.put_line ('Vnculo de quantidade do item 2236 (1) validado!' || CHR(10) || CHR(10));
     end if;   
  end;
 
  ------------------------------------------------------------------------------------------ 
/* 2) Os processos do detalhe do item 2236 devem ser os processos informados nos itens
      2.192 ou 2.195 para as classes processuais consideradas nesse item. */
  declare
  existe boolean := false;
  
  begin  
  dbms_output.put_line('Verificao do item 2236 (2).' || CHR(10) || CHR(10) || 
                       'Processos que esto no detalhe do item 2236 e no esto no detalhe do item 2192 nem do 2195:' || CHR(10) || CHR(10));
  
  /* Cursor que identifica os processos que esto no detalhe do item 2236 e no esto no detalhe do item 2192 e 2195 */
  FOR c2236 IN (select num_interno_processo, proc.nr_processo_atual
     from egt_info_processo infp, sap.tb_processo proc
     where infp.num_interno_processo = proc.sq_processo
     and num_item = 2236 and
           num_remessa = remessa and
           num_lote = lote)
           
           LOOP
           FOR c2192_2195 IN (select num_interno_processo
                         from egt_info_processo
                         where (num_item = 2192 or num_item = 2195) and
                               num_remessa = remessa and
                               num_lote = lote)
                         
                         LOOP
                         if(c2236.num_interno_processo = c2192_2195.num_interno_processo)
                         then
                             existe := true;
                             exit;
                         end if;                       
                         END LOOP;
                         
                         if(not existe)
                         then dbms_output.put_line(c2236.num_interno_processo || '    ' || c2236.nr_processo_atual);                  
                         end if;
                         existe := false;
           END LOOP;
           dbms_output.put_line(CHR(10) || '-----------------------------------------------------');         
  end;

  ------------------------------------------------------------------------------------------
/* 1) A quantidade do item 2237 deve ser 0 e o Valor deve ser nulo 
      se os itens 2.192 e 2.195 forem iguais a zero; */
  declare
  q2237 number(5) := 0; 
 
  begin
  select SUM(num_quantidade_item)
    into q2237
    from egt_info_item
   where num_item = 2237
     and num_remessa = remessa
     and num_lote = lote;
  
  select SUM(num_quantidade_item)
    into qSoma
    from egt_info_item
   where (num_item = 2192 or num_item = 2195)
     and num_remessa = remessa
     and num_lote = lote;
                  
     if (qSoma = 0 and q2237 <> 0) then
        dbms_output.put_line ('Violao do vnculo de quantidade do item 2237 (1)!' || CHR(10) || CHR(10) ||
                              'A quantidade do item 2237 no  0!' || CHR(10) || CHR(10));
     else
        dbms_output.put_line ('Vnculo de quantidade do item 2237 (1) validado!' || CHR(10) || CHR(10));
     end if;   
  end;
 
  ------------------------------------------------------------------------------------------ 
/* 2) Os processos do detalhe do item 2237 devem ser os processos informados nos itens
      2.192 ou 2.195 para as classes processuais consideradas nesse item. */
  declare
  existe boolean := false;
  
  begin  
  dbms_output.put_line('Verificao do item 2237 (2).' || CHR(10) || CHR(10) || 
                       'Processos que esto no detalhe do item 2237 e no esto no detalhe do item 2192 nem do 2195:' || CHR(10) || CHR(10));
  
  /* Cursor que identifica os processos que esto no detalhe do item 2236 e no esto no detalhe do item 2192 e 2195 */
  FOR c2237 IN (select num_interno_processo, proc.nr_processo_atual
     from egt_info_processo infp, sap.tb_processo proc
     where infp.num_interno_processo = proc.sq_processo
     and num_item = 2237 and
           num_remessa = remessa and
           num_lote = lote)
           
           LOOP
           FOR c2192_2195 IN (select num_interno_processo
                         from egt_info_processo
                         where (num_item = 2192 or num_item = 2195) and
                               num_remessa = remessa and
                               num_lote = lote)
                         
                         LOOP
                         if(c2237.num_interno_processo = c2192_2195.num_interno_processo)
                         then
                             existe := true;
                             exit;
                         end if;                       
                         END LOOP;
                         
                         if(not existe)
                         then dbms_output.put_line(c2237.num_interno_processo || '    ' || c2237.nr_processo_atual);                  
                         end if;
                         existe := false;
           END LOOP;
           dbms_output.put_line(CHR(10) || '-----------------------------------------------------');         
  end;

  ------------------------------------------------------------------------------------------
/* 1) A quantidade do item 2239 deve ser 0 e o Valor deve ser nulo
      se os itens 2.220 e 2.221 forem iguais a zero; */
  declare
  q2239 number(5) := 0; 
 
  begin
  select SUM(num_quantidade_item)
    into q2239
    from egt_info_item
   where num_item = 2239
     and num_remessa = remessa
     and num_lote = lote;
  
  select SUM(num_quantidade_item)
    into qSoma
    from egt_info_item
   where (num_item = 2220 or num_item = 2221)
     and num_remessa = remessa
     and num_lote = lote;
                  
     if (qSoma = 0 and q2239 <> 0) then
        dbms_output.put_line ('Violao do vnculo de quantidade do item 2239 (1)!' || CHR(10) || CHR(10) ||
                              'A quantidade do item 2239 no  0!' || CHR(10) || CHR(10));
     else
        dbms_output.put_line ('Vnculo de quantidade do item 2239 (1) validado!' || CHR(10) || CHR(10));
     end if;   
  end;

  ------------------------------------------------------------------------------------------  
/* 2) Os processos do detalhe do item 2239 devem ser os processos informados nos itens
      2.220 ou 2.221 para as classes processuais consideradas nesse item. */
  declare
  existe boolean := false;
  
  begin  
  dbms_output.put_line('Verificao do item 2239 (2).' || CHR(10) || CHR(10) || 
                       'Processos que esto no detalhe do item 2239 e no esto no detalhe do item 2220 nem do 2221:' || CHR(10) || CHR(10));
  
  /* Cursor que identifica os processos que esto no detalhe do item 2239 e no esto no detalhe do item 2220 e 2221 */
  FOR c2239 IN (select num_interno_processo, proc.nr_processo_atual
     from egt_info_processo infp, sap.tb_processo proc
     where infp.num_interno_processo = proc.sq_processo
     and num_item = 2239 and
           num_remessa = remessa and
           num_lote = lote)
           
           LOOP
           FOR c2220_2221 IN (select num_interno_processo
                         from egt_info_processo
                         where (num_item = 2220 or num_item = 2221) and
                               num_remessa = remessa and
                               num_lote = lote)
                         
                         LOOP
                         if(c2239.num_interno_processo = c2220_2221.num_interno_processo)
                         then
                             existe := true;
                             exit;
                         end if;                       
                         END LOOP;
                         
                         if(not existe)
                         then dbms_output.put_line(c2239.num_interno_processo || '    ' || c2239.nr_processo_atual);                  
                         end if;
                         existe := false;
           END LOOP;
           dbms_output.put_line(CHR(10) || '-----------------------------------------------------');         
  end;
  
    ------------------------------------------------------------------------------------------
/* 1) A quantidade do item 2240 deve ser 0 e o Valor deve ser nulo 
      se os itens 2.220 e 2.221 forem iguais a zero; */
  declare
  q2240 number(5) := 0; 
 
  begin
  select SUM(num_quantidade_item)
    into q2240
    from egt_info_item
   where num_item = 2240
     and num_remessa = remessa
     and num_lote = lote;
  
  select SUM(num_quantidade_item)
    into qSoma
    from egt_info_item
   where (num_item = 2220 or num_item = 2221)
     and num_remessa = remessa
     and num_lote = lote;
                  
     if (qSoma = 0 and q2240 <> 0) then
        dbms_output.put_line ('Violao do vnculo de quantidade do item 2240 (1)!' || CHR(10) || CHR(10) ||
                              'A quantidade do item 2240 no  0!' || CHR(10) || CHR(10));
     else
        dbms_output.put_line ('Vnculo de quantidade do item 2240 (1) validado!' || CHR(10) || CHR(10));
     end if;   
  end;
  
    ------------------------------------------------------------------------------------------
/* 2) Os processos do detalhe do item 2240 devem ser os processos informados nos itens
      2.220 para as classes processuais consideradas nesse item. */
  declare
  existe boolean := false;
  
  begin  
  dbms_output.put_line('Verificao do item 2240 (2).' || CHR(10) || CHR(10) || 
                       'Processos que esto no detalhe do item 2240 e no esto no detalhe do item 2220:' || CHR(10) || CHR(10));
  
  /* Cursor que identifica os processos que esto no detalhe do item 2240 e no esto no detalhe do item 2220*/
  FOR c2240 IN (select num_interno_processo, proc.nr_processo_atual
     from egt_info_processo infp, sap.tb_processo proc
     where infp.num_interno_processo = proc.sq_processo
     and num_item = 2240 and
           num_remessa = remessa and
           num_lote = lote)
           
           LOOP
           FOR c2220 IN (select num_interno_processo
                         from egt_info_processo
                         where num_item = 2220 and
                               num_remessa = remessa and
                               num_lote = lote)
                         
                         LOOP
                         if(c2240.num_interno_processo = c2220.num_interno_processo)
                         then
                             existe := true;
                             exit;
                         end if;                       
                         END LOOP;
                         
                         if(not existe)
                         then dbms_output.put_line(c2240.num_interno_processo || '    ' || c2240.nr_processo_atual);                  
                         end if;
                         existe := false;
           END LOOP;
           dbms_output.put_line(CHR(10) || '-----------------------------------------------------');         
  end;
  
------------------------------------------------------------------------------------------   
/* 1) A quantidade do item 2241 deve ser 0 e o Valor deve ser nulo 
      se os itens 2.220 e 2.221 forem iguais a zero; */
  declare
  q2241 number(5) := 0; 
 
  begin
  select SUM(num_quantidade_item)
    into q2241
    from egt_info_item
   where num_item = 2241
     and num_remessa = remessa
     and num_lote = lote;
  
  select SUM(num_quantidade_item)
    into qSoma
    from egt_info_item
   where (num_item = 2220 or num_item = 2221)
     and num_remessa = remessa
     and num_lote = lote;
                  
     if (qSoma = 0 and q2241 <> 0) then
        dbms_output.put_line ('Violao do vnculo de quantidade do item 2241 (1)!' || CHR(10) || CHR(10) ||
                               'A quantidade do item 2241 no  0!' || CHR(10) || CHR(10));
     else
        dbms_output.put_line ('Vnculo de quantidade do item 2241 (1) validado!' || CHR(10) || CHR(10));
     end if;   
     dbms_output.put_line(CHR(10) || '-----------------------------------------------------');
  end;
  
------------------------------------------------------------------------------------------      
/* 1) A quantidade do item 2243 deve ser 0 e o Valor deve ser nulo 
      se a soma dos itens 2.206 e 2.207 for igual a zero; */
  declare
  q2243 number(5) := 0; 
 
  begin 
  select SUM(num_quantidade_item)
    into q2243
    from egt_info_item
   where num_item = 2243
     and num_remessa = remessa
     and num_lote = lote;
  
  select SUM(num_quantidade_item)
    into qSoma
    from egt_info_item
   where (num_item = 2206 or num_item = 2207)
     and num_remessa = remessa
     and num_lote = lote;
                  
     if (qSoma = 0 and q2243 <> 0) then
        dbms_output.put_line ('Violao do vnculo de quantidade do item 2243 (1)!' || CHR(10) || CHR(10) ||
                              'A quantidade do item 2243 no  0!' || CHR(10) || CHR(10));
     else
        dbms_output.put_line ('Vnculo de quantidade do item 2243 (1) validado!' || CHR(10) || CHR(10));
     end if;   
  end;
  
------------------------------------------------------------------------------------------    
/* 2) Os processos do detalhe do item 2243 devem ser os processos informados
      nos itens 2.206 e 2.207 para as classes processuais consideradas nesse item. */
  declare
  existe boolean := false;
  
  begin   
  dbms_output.put_line('Verificao do item 2243 (2).' || CHR(10) || CHR(10) || 
                       'Processos que esto no detalhe do item 2243 e no esto no detalhe dos itens 2206 e 2207:' || CHR(10) || CHR(10));
  
  /* Cursor que identifica os processos que esto no detalhe do item 2243 e no esto no detalhe dos itens 2206 e 2207 */
  FOR c2243 IN (select num_interno_processo, proc.nr_processo_atual
     from egt_info_processo infp, sap.tb_processo proc
     where infp.num_interno_processo = proc.sq_processo
     and num_item = 2243 and
           num_remessa = remessa and
           num_lote = lote)
           
           LOOP
           FOR c2206_2207 IN (select num_interno_processo
                         from egt_info_processo
                         where (num_item = 2206 or num_item = 2207) and
                               num_remessa = remessa and
                               num_lote = lote)
                         
                         LOOP
                         if(c2243.num_interno_processo = c2206_2207.num_interno_processo)
                         then
                             existe := true;
                             exit;
                         end if;                       
                         END LOOP;
                         
                         if(not existe)
                         then dbms_output.put_line(c2243.num_interno_processo || '    ' || c2243.nr_processo_atual);                  
                         end if;
                         existe := false;
           END LOOP;
           dbms_output.put_line(CHR(10) || '-----------------------------------------------------');          
  end;
  
------------------------------------------------------------------------------------------    
  /* 1) A quantidade do item 2247 deve ser 0 e o Valor deve ser nulo 
        se o item 2.213 for igual a zero; */
  declare
  q2247 number(5) := 0;
  q2213 number(5) := 0; 
 
  begin 
  select SUM(num_quantidade_item)
    into q2247
    from egt_info_item
   where num_item = 2247
     and num_remessa = remessa
     and num_lote = lote;
  
  select SUM(num_quantidade_item)
    into q2213
    from egt_info_item
   where num_item = 2213
     and num_remessa = remessa
     and num_lote = lote;
                  
     if (q2213 = 0 and q2247 <> 0) then
        dbms_output.put_line ('Violao do vnculo de quantidade do item 2247 (1)!' || CHR(10) || CHR(10) ||
                              'A quantidade do item 2247 no  0!' || CHR(10) || CHR(10));
     else
        dbms_output.put_line ('Vnculo de quantidade do item 2247 (1) validado!' || CHR(10) || CHR(10));
     end if;   
  end;
  
------------------------------------------------------------------------------------------    
/* 2) Os processos do detalhe do item 2247 devem ser os processos informados
      no item 2.213 para as classes processuais consideradas nesse item. */
  declare
  existe boolean := false;
  
  begin  
  dbms_output.put_line('Verificao do item 2247 (2).' || CHR(10) || CHR(10) || 
                       'Processos que esto no detalhe do item 2247 e no esto no detalhe do item 2213:' || CHR(10) || CHR(10));
  
  /* Cursor que identifica os processos que esto no detalhe do item 2247 e no esto no detalhe do item 2213 */
  FOR c2247 IN (select num_interno_processo, proc.nr_processo_atual
     from egt_info_processo infp, sap.tb_processo proc
     where infp.num_interno_processo = proc.sq_processo
     and num_item = 2247 and
           num_remessa = remessa and
           num_lote = lote)
           
           LOOP
           FOR c2213 IN (select num_interno_processo
                         from egt_info_processo
                         where num_item = 2213 and
                               num_remessa = remessa and
                               num_lote = lote)
                         
                         LOOP
                         if(c2247.num_interno_processo = c2213.num_interno_processo)
                         then
                             existe := true;
                             exit;
                         end if;                       
                         END LOOP;
                         
                         if(not existe)
                         then dbms_output.put_line(c2247.num_interno_processo || '    ' || c2247.nr_processo_atual);                  
                         end if;
                         existe := false;
           END LOOP;
           dbms_output.put_line(CHR(10) || '-----------------------------------------------------');          
  end;
  
------------------------------------------------------------------------------------------    
/* 1) A quantidade do item 2258 deve ser 0 e o Valor deve ser nulo 
      se a soma dos itens 2.271 e 2.272 for igual a zero; */
  declare
  q2258 number(5) := 0; 
 
  begin
  select SUM(num_quantidade_item)
    into q2258
    from egt_info_item
   where num_item = 2258
     and num_remessa = remessa
     and num_lote = lote;
  
  select SUM(num_quantidade_item)
    into qSoma
    from egt_info_item
   where (num_item = 2271 or num_item = 2272)
     and num_remessa = remessa
     and num_lote = lote;
                  
     if (qSoma = 0 and q2258 <> 0) then
        dbms_output.put_line ('Violao do vnculo de quantidade do item 2258 (1)!' || CHR(10) || CHR(10) ||
                              'A quantidade do item 2258 no  0!' || CHR(10) || CHR(10));
     else
        dbms_output.put_line ('Vnculo de quantidade do item 2258 (1) validado!' || CHR(10) || CHR(10));
     end if;   
  end;
   
------------------------------------------------------------------------------------------   
/* 2) A quantidade do item 2258 deve ser maior que 0 e o Valor deve ser maior ou igual a 0
 se a soma dos itens 2.271 e 2.272 for maior que zero para as classes processuais consideradas nesse item;*/  
  declare
  q2258 number := 0;
   
  begin 
  select SUM(num_quantidade_item)
    into q2258
    from egt_info_item
   where num_item = 2258
     and num_remessa = remessa
     and num_lote = lote;
  
  select SUM(num_quantidade_item)
    into qSoma
    from egt_info_item
   where (num_item = 2271 or num_item = 2272)
     and num_remessa = remessa
     and num_lote = lote;

     if (qSoma <> 0 and q2258 = 0) then
        dbms_output.put_line ('Violao do vnculo de quantidade do item 2258 (2)!' || CHR(10) || CHR(10)||
                              'A quantidade do item 2258 deveria ser maior do que 0!' || CHR(10) || CHR(10) );
     else
        dbms_output.put_line ('Vnculo de quantidade do item 2258 (2) validado!' || CHR(10) || CHR(10) );
     end if;   
  end;
  
------------------------------------------------------------------------------------------    
/* 3) Os processos do detalhe do item 2258 devem ser os processos informados
      nos itens 2.271 e 2.272 para as classes processuais consideradas nesse item. */
  declare
  existe boolean := false;
  
  begin  
  dbms_output.put_line('Verificao do item 2258 (3).' || CHR(10) || CHR(10) || 
                       'Processos que esto no detalhe do item 2258 e no esto no detalhe dos itens 2271 e 2272:' || CHR(10) || CHR(10));
  
  /* Cursor que identifica os processos que esto no detalhe do item 2258 e no esto no detalhe dos itens 2271 e 2272 */
  FOR c2258 IN (select num_interno_processo, proc.nr_processo_atual
     from egt_info_processo infp, sap.tb_processo proc
     where infp.num_interno_processo = proc.sq_processo
     and num_item = 2258 and
           num_remessa = remessa and
           num_lote = lote)
           
           LOOP
           FOR c2271_2272 IN (select num_interno_processo
                         from egt_info_processo
                         where (num_item = 2271 or num_item = 2272) and
                               num_remessa = remessa and
                               num_lote = lote)
                         
                         LOOP
                         if(c2258.num_interno_processo = c2271_2272.num_interno_processo)
                         then
                             existe := true;
                             exit;
                         end if;                       
                         END LOOP;
                         
                         if(not existe)
                         then dbms_output.put_line(c2258.num_interno_processo || '    ' || c2258.nr_processo_atual);                  
                         end if;
                         existe := false;
           END LOOP;
           dbms_output.put_line(CHR(10) || '-----------------------------------------------------');          
  end;
   
------------------------------------------------------------------------------------------   
  /* 3) Os processos do detalhe do item 2258 devem ser os processos informados
      nos itens 2.271 e 2.272 para as classes processuais consideradas nesse item. */
  declare
  existe boolean := false;
  
  begin  
  dbms_output.put_line('Verificao do item 2258 (3).' || CHR(10) || CHR(10) || 
                       'Processos que esto no detalhe dos itens 2271 e 2272 e no esto no detalhe do item 2258:' || CHR(10) || CHR(10));
  
  /* Cursor que identifica os processos que esto no detalhe dos itens 2271 e 2272 e no esto no detalhe do item 2258*/
  FOR c2271_2272 IN (select num_interno_processo, proc.nr_processo_atual
     from egt_info_processo infp, sap.tb_processo proc
     where infp.num_interno_processo = proc.sq_processo
     and (num_item = 2271 or num_item = 2272)
           and num_remessa = remessa
           and num_lote = lote)
           
           LOOP
           FOR c2258 IN (select num_interno_processo
                         from egt_info_processo
                         where num_item = 2258 and
                               num_remessa = remessa and
                               num_lote = lote)
                         
                         LOOP
                         if(c2271_2272.num_interno_processo = c2258.num_interno_processo)
                         then
                             existe := true;
                             exit;
                         end if;                       
                         END LOOP;
                         
                         if(not existe)
                         then dbms_output.put_line(c2271_2272.num_interno_processo || '    ' || c2271_2272.nr_processo_atual);                  
                         end if;
                         existe := false;
           END LOOP;
           dbms_output.put_line(CHR(10) || '-----------------------------------------------------');          
  end;
   
------------------------------------------------------------------------------------------   
  /* 1) A quantidade do item 2266 deve ser 0 e o Valor deve ser nulo 
        se o item 2.262 for igual a zero; */
  declare
  q2266 number(5) := 0;
  q2262 number(5) := 0; 
 
  begin
  select SUM(num_quantidade_item)
    into q2266
    from egt_info_item
   where num_item = 2266
     and num_remessa = remessa
     and num_lote = lote;
  
  select SUM(num_quantidade_item)
    into q2262
    from egt_info_item
   where num_item = 2262
     and num_remessa = remessa
     and num_lote = lote;
                  
     if (q2262 = 0 and q2266 <> 0) then
        dbms_output.put_line ('Violao do vnculo de quantidade do item 2266 (1)!' || CHR(10) || CHR(10) ||
                              'A quantidade do item 2266 no  0!' || CHR(10) || CHR(10));
     else
        dbms_output.put_line ('Vnculo de quantidade do item 2266 (1) validado!' || CHR(10) || CHR(10));
     end if;   
  end;
  
------------------------------------------------------------------------------------------    
/* 2) Os processos do detalhe do item 2266 devem ser os processos informados
      no item 2.262 para as classes processuais consideradas nesse item. */
  declare
  existe boolean := false;
  
  begin  
  dbms_output.put_line('Verificao do item 2266 (2).' || CHR(10) || CHR(10) || 
                       'Processos que esto no detalhe do item 2266 e no esto no detalhe do item 2262:' || CHR(10) || CHR(10));
  
  /* Cursor que identifica os processos que esto no detalhe do item 2266 e no esto no detalhe do item 2262 */
  FOR c2266 IN (select num_interno_processo, proc.nr_processo_atual
     from egt_info_processo infp, sap.tb_processo proc
     where infp.num_interno_processo = proc.sq_processo
     and num_item = 2266 and
           num_remessa = remessa and
           num_lote = lote)
           
           LOOP
           FOR c2262 IN (select num_interno_processo
                         from egt_info_processo
                         where num_item = 2262 and
                               num_remessa = remessa and
                               num_lote = lote)
                         
                         LOOP
                         if(c2266.num_interno_processo = c2262.num_interno_processo)
                         then
                             existe := true;
                             exit;
                         end if;                       
                         END LOOP;
                         
                         if(not existe)
                         then dbms_output.put_line(c2266.num_interno_processo || '    ' || c2266.nr_processo_atual);                  
                         end if;
                         existe := false;
           END LOOP;
           dbms_output.put_line(CHR(10) || '-----------------------------------------------------');          
  end;
   
end;
