/*

Script para validar as Regras No Temporais - rea Judiciria - e_Gesto 2o grau.

Validao da regra:
- Todos os campos definidos nos itens como obrigatrios no podem estar nulos


Desenvolvido por Lucas Aranha Barreto (lucas.barreto@trt1.jus.br)
STI - CGSP (Coordenadoria de Gesto de Sistemas e Portal)
TRT 1 Regio - RJ 


---------------------------------------------------------------------------------------------
Obs: Nesse script a tabela interna de processos do TRT1 (TB_PROCESSO)  referenciada. Essa 
tabela contm o atributo SQ_PROCESSO, que corresponde ao NUM_INTERNO_PROCESSO do e-Gesto. Uma
juno  feita nas tabelas TB_PROCESSO e EGT_INFO_PROCESSO atravs desses atributos 
(SQ_PROCESSO e NUM_INTERNO_PROCESSO) para o relatrio poder mostrar o nmero CNJ 
do processo (NR_PROCESSO_ATUAL da TB_PROCESSO). 

Sendo assim, o script tem que ser adaptado para funcionar na estrutura especfica do 
banco de dados de outro regional.
---------------------------------------------------------------------------------------------
*/

DECLARE
remessa NUMBER(10) := 20021; --<< PREENCHER: nmero da remessa a ser validada
lote NUMBER (2) := 1;        --<< PREENCHER: nmero do lote a ser validado

BEGIN

-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios: NUM_RAMO_ATIVIDADE e COD_ENTE_PUBLICO */

   dbms_output.put_line('Processos com o atributo NUM_RAMO_ATIVIDADE nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');
                  
            
/*
Cursor implcito que armazena os campos obrigatrios que esto nulos. 
Nesse caso, os itens 2123 e 2124 tm os atributos comentados acima como
obrigatrios (NUM_RAMO_ATIVIDADE e COD_ENTE_PUBLICO). O restante do cdigo foi 
estruturado da mesma maneira, um comentrio com um conjunto de campos obrigatrios
e logo em seguida a verificao dos itens que devem ter esses campos no nulos.*/

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2123,2124) and NUM_REMESSA = remessa 
                     and NUM_LOTE = lote 
                     and NUM_RAMO_ATIVIDADE is NULL) 
                     
       /* Impresso do nmero dos processos/item que esto com campo obrigatrio nulo */
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

   dbms_output.put_line('Processos com o atributo COD_ENTE_PUBLICO nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, NUM_RAMO_ATIVIDADE, proc.NR_PROCESSO_ATUAL 
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2123,2124) and NUM_REMESSA = remessa
                     and NUM_LOTE = lote 
                     and COD_ENTE_PUBLICO is NULL) 
       LOOP
           IF(resultado.NUM_RAMO_ATIVIDADE in (1201,1202,1203)) -- Verifica se  um ente pblico
           THEN dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
           END IF;
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios: NUM_RELATOR e NUM_UNIDADE */      

   dbms_output.put_line('Processos com o atributo NUM_RELATOR nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2134,2137,2138,2139,2142,2145,2147,2148,
                                    2150,2151,2152,2153,2154,2156,2157,2159,2160,
                                    2161,2186,2187,2198,2199,2200,
                                    2201,2206,2220,2221) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote 
                     and NUM_RELATOR is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));


   dbms_output.put_line('Processos com o atributo NUM_UNIDADE nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2134,2137,2138,2139,2142,2145,2147,2148,
                                        2150,2151,2152,2153,2154,2156,2157,2159,2160,
                                        2161,2186,2187,2198,2199,2200,
                                        2201,2206,2220,2221) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_UNIDADE is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios: NUM_MAG_VISTA e NUM_UNIDADE */   

  dbms_output.put_line('Processos com o atributo NUM_MAG_VISTA nulo:' || CHR(10) || CHR(10) ||
                     'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2164,2166,2168,2169) and NUM_REMESSA = remessa 
                     and NUM_LOTE = lote
                     and NUM_MAG_VISTA is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));


   dbms_output.put_line('Processos com o atributo NUM_UNIDADE nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2164,2166,2168,2169) and NUM_REMESSA = remessa 
                     and NUM_LOTE = lote 
                     and NUM_UNIDADE is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));


-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios: NUM_REVISOR e NUM_UNIDADE */   

   dbms_output.put_line('Processos com o atributo NUM_REVISOR nulo:' || CHR(10) || CHR(10) ||
                     'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2172,2174,2175,2176,2177,2179,2180) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote 
                     and NUM_REVISOR is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));


   dbms_output.put_line('Processos com o atributo NUM_UNIDADE nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2172,2174,2175,2176,2177,2179,2180) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote 
                     and NUM_UNIDADE is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios: NUM_RELATOR, COD_TIPO_SESSAO, DTA_SESSAO e NUM_UNIDADE*/  

 dbms_output.put_line('Processos com o atributo NUM_RELATOR nulo:' || CHR(10) || CHR(10) ||
                     'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2188,2189) and NUM_REMESSA = remessa
                     and NUM_LOTE = lote
                     and NUM_RELATOR is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

 dbms_output.put_line('Processos com o atributo COD_TIPO_SESSAO nulo:' || CHR(10) || CHR(10) ||
                     'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2188,2189) and NUM_REMESSA = remessa 
                     and NUM_LOTE = lote
                     and COD_TIPO_SESSAO is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));


   dbms_output.put_line('Processos com o atributo DTA_SESSAO nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2188,2189) and NUM_REMESSA = remessa 
                     and NUM_LOTE = lote
                     and DTA_SESSAO is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

   dbms_output.put_line('Processos com o atributo NUM_UNIDADE nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2188,2189) and NUM_REMESSA = remessa 
                     and NUM_LOTE = lote 
                     and NUM_UNIDADE is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));    

-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios: NUM_RELATOR ou NUM_REDATOR, NUM_UNIDADE */  

  dbms_output.put_line('Processos com o atributo NUM_RELATOR e NUM_REDATOR nulos:' || CHR(10) || CHR(10) ||
                     'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2192,2193,2195,2196,2204,2208,2210,2211,
                     2213,2214,2216,2217,2369,2370,2371,2372,2373,2374,2375,
                     2376,2377,2378,2379,2380,2381,2382,2383,2384,2385,2386,
                     2387,2389,2390,2391,2392,2393,2394) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_RELATOR is NULL and NUM_REDATOR is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));


   dbms_output.put_line('Processos com o atributo NUM_UNIDADE nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2192,2193,2195,2196,2204,2208,2210,2211,
                     2213,2214,2216,2217,2369,2370,2371,2372,2373,2374,2375,
                     2376,2377,2378,2379,2380,2381,2382,2383,2384,2385,2386,
                     2387,2389,2390,2391,2392,2393,2394) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote 
                     and NUM_UNIDADE is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios: NUM_RELATOR ou NUM_REVISOR, NUM_UNIDADE */  

  dbms_output.put_line('Processos com o atributo NUM_RELATOR e NUM_REVISOR nulos:' || CHR(10) || CHR(10) ||
                     'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2182,2183,2184) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_RELATOR is NULL and NUM_REVISOR is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));


   dbms_output.put_line('Processos com o atributo NUM_UNIDADE nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2182,2183,2184) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote 
                     and NUM_UNIDADE is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios: NUM_REDATOR, NUM_UNIDADE */  

  dbms_output.put_line('Processos com o atributo NUM_REDATOR nulo:' || CHR(10) || CHR(10) ||
                     'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2207)
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_REDATOR is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));


   dbms_output.put_line('Processos com o atributo NUM_UNIDADE nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2207) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_UNIDADE is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios:  
               DTA_EVENTO_INICIAL (EGT_INFO_PROCESSO)
               DTA_EVENTO_FINAL   (EGT_INFO_PROCESSO)
               NUM_QUANTIDADE_ITEM(EGT_INFO_ITEM)
               NUM_VALOR_ITEM     (EGT_INFO_ITEM)
*/

   dbms_output.put_line('Processos com o atributo DTA_EVENTO_INICIAL nulo:' || CHR(10) || CHR(10) ||
                     'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2227,2228,2236,2237,2239,2240,2241,2245) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and DTA_EVENTO_INICIAL is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));


   dbms_output.put_line('Processos com o atributo DTA_EVENTO_FINAL nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2227,2228,2236,2237,2239,2240,2241,2245) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and DTA_EVENTO_FINAL is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

   dbms_output.put_line('Ocorrncias com o atributo NUM_QUANTIDADE_ITEM nulo:' || CHR(10) || CHR(10) ||
                        '--------------------  NUM_ITEM');

   FOR resultado IN (select NUM_ITEM from egt_info_item
                     where NUM_ITEM in (2227,2228,2236,2237,2239,2240,2241,2245) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_QUANTIDADE_ITEM is NULL) 
       LOOP
       dbms_output.put_line('--------' || '               ' || resultado.NUM_ITEM);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10)); 

   dbms_output.put_line('Ocorrncias com o atributo NUM_VALOR_ITEM nulo:' || CHR(10) || CHR(10) ||
                        '--------------------  NUM_ITEM');

   FOR resultado IN (select NUM_ITEM, NUM_QUANTIDADE_ITEM from egt_info_item
                     where NUM_ITEM in (2227,2228,2236,2237,2239,2240,2241,2245) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_VALOR_ITEM is NULL) 
       LOOP
       IF (resultado.NUM_QUANTIDADE_ITEM > 0)
       THEN dbms_output.put_line('--------' || '               ' || resultado.NUM_ITEM);
       END IF;
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10)); 

-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios: 
               NUM_RELATOR        (EGT_INFO_PROCESSO)
               DTA_EVENTO_INICIAL (EGT_INFO_PROCESSO)
               DTA_EVENTO_FINAL   (EGT_INFO_PROCESSO)
               NUM_QUANTIDADE_ITEM(EGT_INFO_ITEM)
               NUM_VALOR_ITEM     (EGT_INFO_ITEM)
*/

dbms_output.put_line('Processos com o atributo NUM_RELATOR nulo:' || CHR(10) || CHR(10) ||
                     'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2230) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote 
                     and NUM_RELATOR is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));


   dbms_output.put_line('Processos com o atributo DTA_EVENTO_INICIAL nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2230) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and DTA_EVENTO_INICIAL is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

   dbms_output.put_line('Processos com o atributo DTA_EVENTO_FINAL nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2230)
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and DTA_EVENTO_FINAL is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10)); 

   dbms_output.put_line('Ocorrncias com o atributo NUM_QUANTIDADE_ITEM nulo:' || CHR(10) || CHR(10) ||
                        '--------------------  NUM_ITEM');

   FOR resultado IN (select NUM_ITEM from egt_info_item
                     where NUM_ITEM in (2230) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_QUANTIDADE_ITEM is NULL) 
       LOOP
       dbms_output.put_line('--------' || '               ' || resultado.NUM_ITEM);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10)); 

   dbms_output.put_line('Ocorrncias com o atributo NUM_VALOR_ITEM nulo:' || CHR(10) || CHR(10) ||
                        '--------------------  NUM_ITEM');

   FOR resultado IN (select NUM_ITEM, NUM_QUANTIDADE_ITEM from egt_info_item
                     where NUM_ITEM in (2230) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_VALOR_ITEM is NULL) 
       LOOP
       IF (resultado.NUM_QUANTIDADE_ITEM > 0)
       THEN dbms_output.put_line('--------' || '               ' || resultado.NUM_ITEM);
       END IF;
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10)); 
 
-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios:       
               NUM_REVISOR        (EGT_INFO_PROCESSO)
               DTA_EVENTO_INICIAL (EGT_INFO_PROCESSO)
               DTA_EVENTO_FINAL   (EGT_INFO_PROCESSO)
               NUM_QUANTIDADE_ITEM(EGT_INFO_ITEM)
               NUM_VALOR_ITEM (EGT_INFO_ITEM)
*/

dbms_output.put_line('Processos com o atributo NUM_REVISOR nulo:' || CHR(10) || CHR(10) ||
                     'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2232) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_REVISOR is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));


   dbms_output.put_line('Processos com o atributo DTA_EVENTO_INICIAL nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2232) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and DTA_EVENTO_INICIAL is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

   dbms_output.put_line('Processos com o atributo DTA_EVENTO_FINAL nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2232) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and DTA_EVENTO_FINAL is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10)); 

   dbms_output.put_line('Ocorrncias com o atributo NUM_QUANTIDADE_ITEM nulo:' || CHR(10) || CHR(10) ||
                        '--------------------  NUM_ITEM');

   FOR resultado IN (select NUM_ITEM from egt_info_item
                     where NUM_ITEM in (2232) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_QUANTIDADE_ITEM is NULL) 
       LOOP
       dbms_output.put_line('--------' || '               ' || resultado.NUM_ITEM);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10)); 

   dbms_output.put_line('Ocorrncias com o atributo NUM_VALOR_ITEM nulo:' || CHR(10) || CHR(10) ||
                        '--------------------  NUM_ITEM');

   FOR resultado IN (select NUM_ITEM, NUM_QUANTIDADE_ITEM from egt_info_item
                     where NUM_ITEM in (2232) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_VALOR_ITEM is NULL) 
       LOOP
       IF (resultado.NUM_QUANTIDADE_ITEM > 0)
       THEN dbms_output.put_line('--------' || '               ' || resultado.NUM_ITEM);
       END IF;
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10)); 

-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios:  
               NUM_UNIDADE        (EGT_INFO_PROCESSO)
               DTA_EVENTO_INICIAL (EGT_INFO_PROCESSO)
               DTA_EVENTO_FINAL   (EGT_INFO_PROCESSO)
               NUM_QUANTIDADE_ITEM(EGT_INFO_ITEM)
               NUM_VALOR_ITEM     (EGT_INFO_ITEM)
*/

  dbms_output.put_line('Processos com o atributo NUM_UNIDADE nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2234,2247) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_UNIDADE is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));
  
  dbms_output.put_line('Processos com o atributo DTA_EVENTO_INICIAL nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2234,2247) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and DTA_EVENTO_INICIAL is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

   dbms_output.put_line('Processos com o atributo DTA_EVENTO_FINAL nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2234,2247) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and DTA_EVENTO_FINAL is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10)); 

   dbms_output.put_line('Ocorrncias com o atributo NUM_QUANTIDADE_ITEM nulo:' || CHR(10) || CHR(10) ||
                        '--------------------  NUM_ITEM');

   FOR resultado IN (select NUM_ITEM from egt_info_item
                     where NUM_ITEM in (2234,2247) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_QUANTIDADE_ITEM is NULL) 
       LOOP
       dbms_output.put_line('--------' || '               ' || resultado.NUM_ITEM);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10)); 

   dbms_output.put_line('Ocorrncias com o atributo NUM_VALOR_ITEM nulo:' || CHR(10) || CHR(10) ||
                        '--------------------  NUM_ITEM');

   FOR resultado IN (select NUM_ITEM, NUM_QUANTIDADE_ITEM from egt_info_item
                     where NUM_ITEM in (2234,2247) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_VALOR_ITEM is NULL) 
       LOOP
       IF (resultado.NUM_QUANTIDADE_ITEM > 0)
       THEN dbms_output.put_line('--------' || '               ' || resultado.NUM_ITEM);
       END IF;
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10)); 

-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios:  
               NUM_RELATOR ou NUM_REDATOR        (EGT_INFO_PROCESSO)
               DTA_EVENTO_INICIAL                (EGT_INFO_PROCESSO)
               DTA_EVENTO_FINAL                  (EGT_INFO_PROCESSO)
               NUM_QUANTIDADE_ITEM               (EGT_INFO_ITEM)
               NUM_VALOR_ITEM                    (EGT_INFO_ITEM)
*/

  dbms_output.put_line('Processos com o atributo NUM_RELATOR e NUM_REDATOR nulos:' || CHR(10) || CHR(10) ||
                     'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2243) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_RELATOR is NULL and NUM_REDATOR is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));
  
  dbms_output.put_line('Processos com o atributo DTA_EVENTO_INICIAL nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2243) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and DTA_EVENTO_INICIAL is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

   dbms_output.put_line('Processos com o atributo DTA_EVENTO_FINAL nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2243) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and DTA_EVENTO_FINAL is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10)); 

   dbms_output.put_line('Ocorrncias com o atributo NUM_QUANTIDADE_ITEM nulo:' || CHR(10) || CHR(10) ||
                        '--------------------  NUM_ITEM');

   FOR resultado IN (select NUM_ITEM from egt_info_item
                     where NUM_ITEM in (2243) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_QUANTIDADE_ITEM is NULL) 
       LOOP
       dbms_output.put_line('--------' || '               ' || resultado.NUM_ITEM);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10)); 

   dbms_output.put_line('Ocorrncias com o atributo NUM_VALOR_ITEM nulo:' || CHR(10) || CHR(10) ||
                        '--------------------  NUM_ITEM');

   FOR resultado IN (select NUM_ITEM, NUM_QUANTIDADE_ITEM from egt_info_item
                     where NUM_ITEM in (2243) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_VALOR_ITEM is NULL) 
       LOOP
       IF (resultado.NUM_QUANTIDADE_ITEM > 0)
       THEN dbms_output.put_line('--------' || '               ' || resultado.NUM_ITEM);
       END IF;
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios: 
               NUM_UNIDADE                 (EGT_INFO_PROCESSO)
               NUM_RELATOR ou NUM_REDATOR  (EGT_INFO_PROCESSO)
               DTA_EVENTO_INICIAL          (EGT_INFO_PROCESSO)
               DTA_EVENTO_FINAL            (EGT_INFO_PROCESSO)
               NUM_QUANTIDADE_ITEM         (EGT_INFO_ITEM)
               NUM_VALOR_ITEM              (EGT_INFO_ITEM)
*/

  dbms_output.put_line('Processos com o atributo NUM_UNIDADE nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2243) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_UNIDADE is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

  dbms_output.put_line('Processos com o atributo NUM_RELATOR e NUM_REDATOR nulos:' || CHR(10) || CHR(10) ||
                       'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2243) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_RELATOR is NULL and NUM_REDATOR is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));
       
       dbms_output.put_line('Processos com o atributo DTA_EVENTO_INICIAL nulo:' || CHR(10) || CHR(10) ||
                            'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2243) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and DTA_EVENTO_INICIAL is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

   dbms_output.put_line('Processos com o atributo DTA_EVENTO_FINAL nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2243) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and DTA_EVENTO_FINAL is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10)); 

   dbms_output.put_line('Ocorrncias com o atributo NUM_QUANTIDADE_ITEM nulo:' || CHR(10) || CHR(10) ||
                        '--------------------  NUM_ITEM');

   FOR resultado IN (select NUM_ITEM from egt_info_item
                     where NUM_ITEM in (2243) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_QUANTIDADE_ITEM is NULL) 
       LOOP
       dbms_output.put_line('--------' || '               ' || resultado.NUM_ITEM);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10)); 

   dbms_output.put_line('Ocorrncias com o atributo NUM_VALOR_ITEM nulo:' || CHR(10) || CHR(10) ||
                        '--------------------  NUM_ITEM');

   FOR resultado IN (select NUM_ITEM, NUM_QUANTIDADE_ITEM from egt_info_item
                     where NUM_ITEM in (2243) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_VALOR_ITEM is NULL) 
       LOOP
       IF (resultado.NUM_QUANTIDADE_ITEM > 0)
       THEN dbms_output.put_line('--------' || '               ' || resultado.NUM_ITEM);
       END IF;
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios: NUM_MAG_PRESIDENTE */

dbms_output.put_line('Processos com o atributo NUM_MAG_PRESIDENTE nulo:' || CHR(10) || CHR(10) ||
                     'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2250,2251,2252,2253,2255,2256,2270,2271,2272,
                                      2278,2279,2280,2289,2292,2298,2299) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote 
                     and NUM_MAG_PRESIDENTE is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios: 
               NUM_MAG_PRESIDENTE (EGT_INFO_PROCESSO)
               DTA_EVENTO_INICIAL (EGT_INFO_PROCESSO)
               DTA_EVENTO_FINAL   (EGT_INFO_PROCESSO)
               NUM_QUANTIDADE_ITEM(EGT_INFO_ITEM)
               NUM_VALOR_ITEM     (EGT_INFO_ITEM)
*/

dbms_output.put_line('Processos com o atributo NUM_MAG_PRESIDENTE nulo:' || CHR(10) || CHR(10) ||
                     'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2258) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_MAG_PRESIDENTE is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));


   dbms_output.put_line('Processos com o atributo DTA_EVENTO_INICIAL nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2258) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and DTA_EVENTO_INICIAL is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

   dbms_output.put_line('Processos com o atributo DTA_EVENTO_FINAL nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2258) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and DTA_EVENTO_FINAL is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10)); 

   dbms_output.put_line('Ocorrncias com o atributo NUM_QUANTIDADE_ITEM nulo:' || CHR(10) || CHR(10) ||
                        '--------------------  NUM_ITEM');

   FOR resultado IN (select NUM_ITEM from egt_info_item
                     where NUM_ITEM in (2258) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_QUANTIDADE_ITEM is NULL) 
       LOOP
       dbms_output.put_line('--------' || '               ' || resultado.NUM_ITEM);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10)); 

   dbms_output.put_line('Ocorrncias com o atributo NUM_VALOR_ITEM nulo:' || CHR(10) || CHR(10) ||
                        '--------------------  NUM_ITEM');

   FOR resultado IN (select NUM_ITEM, NUM_QUANTIDADE_ITEM from egt_info_item
                     where NUM_ITEM in (2258) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_VALOR_ITEM is NULL) 
       LOOP
       IF (resultado.NUM_QUANTIDADE_ITEM > 0)
       THEN dbms_output.put_line('--------' || '               ' || resultado.NUM_ITEM);
       END IF;
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10)); 

-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios: NUM_MAG_CORREGEDOR */

dbms_output.put_line('Processos com o atributo NUM_MAG_CORREGEDOR nulo:' || CHR(10) || CHR(10) ||
                     'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2261,2262,2263) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_MAG_CORREGEDOR is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios: 
               NUM_MAG_CORREGEDOR (EGT_INFO_PROCESSO)
               DTA_EVENTO_INICIAL (EGT_INFO_PROCESSO)
               DTA_EVENTO_FINAL   (EGT_INFO_PROCESSO)
               NUM_QUANTIDADE_ITEM(EGT_INFO_ITEM)
               NUM_VALOR_ITEM     (EGT_INFO_ITEM)
*/

dbms_output.put_line('Processos com o atributo NUM_MAG_CORREGEDOR nulo:' || CHR(10) || CHR(10) ||
                     'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2265,2266) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_MAG_CORREGEDOR is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));


   dbms_output.put_line('Processos com o atributo DTA_EVENTO_INICIAL nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2265,2266) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and DTA_EVENTO_INICIAL is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

   dbms_output.put_line('Processos com o atributo DTA_EVENTO_FINAL nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2265,2266) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and DTA_EVENTO_FINAL is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10)); 

   dbms_output.put_line('Ocorrncias com o atributo NUM_QUANTIDADE_ITEM nulo:' || CHR(10) || CHR(10) ||
                        '--------------------  NUM_ITEM');

   FOR resultado IN (select NUM_ITEM from egt_info_item
                     where NUM_ITEM in (2265,2266) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_QUANTIDADE_ITEM is NULL) 
       LOOP
       dbms_output.put_line('--------' || '               ' || resultado.NUM_ITEM);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10)); 

   dbms_output.put_line('Ocorrncias com o atributo NUM_VALOR_ITEM nulo:' || CHR(10) || CHR(10) ||
                        '--------------------  NUM_ITEM');

   FOR resultado IN (select NUM_ITEM, NUM_QUANTIDADE_ITEM from egt_info_item
                     where NUM_ITEM in (2265,2266) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_VALOR_ITEM is NULL) 
       LOOP
       IF (resultado.NUM_QUANTIDADE_ITEM > 0)
       THEN dbms_output.put_line('--------' || '               ' || resultado.NUM_ITEM);
       END IF;
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10)); 

-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios: COD_ENTE_PUBLICO */

dbms_output.put_line('Processos com o atributo COD_ENTE_PUBLICO nulo:' || CHR(10) || CHR(10) ||
                     'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, NUM_RAMO_ATIVIDADE, proc.NR_PROCESSO_ATUAL 
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2314,2315,2333,2334) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and COD_ENTE_PUBLICO is NULL) 
       LOOP
       IF(resultado.NUM_RAMO_ATIVIDADE in (1201,1202,1203)) -- Verifica se  um ente pblico
       THEN dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END IF;
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios: NUM_VALOR_ORIGINAL_HISTORICO, NUM_VALOR_ATUALIZADO */

  dbms_output.put_line('Processos com o atributo NUM_VALOR_ORIGINAL_HISTORICO nulo:' || CHR(10) || CHR(10) ||
                     'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2319,2338) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_VALOR_ORIGINAL_HISTORICO is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));


   dbms_output.put_line('Processos com o atributo NUM_VALOR_ATUALIZADO nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2319,2338) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_VALOR_ATUALIZADO is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios: COD_ENTE_PUBLICO, NUM_VALOR_INTEGRAL_QUITACAO */

  dbms_output.put_line('Processos com o atributo COD_ENTE_PUBLICO nulo:' || CHR(10) || CHR(10) ||
                     'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, NUM_RAMO_ATIVIDADE, proc.NR_PROCESSO_ATUAL 
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2323,2324,2342,2343) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and COD_ENTE_PUBLICO is NULL) 
       LOOP
       IF(resultado.NUM_RAMO_ATIVIDADE in (1201,1202,1203)) -- Verifica se  um ente pblico
       THEN dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END IF;
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));


   dbms_output.put_line('Processos com o atributo NUM_VALOR_INTEGRAL_QUITACAO nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2323,2324,2342,2343) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_VALOR_INTEGRAL_QUITACAO is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios: COD_ENTE_PUBLICO, NUM_VALOR_ATUALIZADO, DTA_OFICIO_REQUISITORIO 
                                        ou DTA_SOLICITACAO_REC_FINANC */

  dbms_output.put_line('Processos com o atributo COD_ENTE_PUBLICO nulo:' || CHR(10) || CHR(10) ||
                     'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, NUM_RAMO_ATIVIDADE, proc.NR_PROCESSO_ATUAL 
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2326,2327,2328,2329) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and COD_ENTE_PUBLICO is NULL) 
       LOOP
       IF(resultado.NUM_RAMO_ATIVIDADE in (1201,1202,1203)) -- Verifica se  um ente pblico
       THEN dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END IF;
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));


   dbms_output.put_line('Processos com o atributo NUM_VALOR_ATUALIZADO nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2326,2327,2328,2329) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_VALOR_ATUALIZADO is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

 dbms_output.put_line('Processos com o atributo DTA_OFICIO_REQUISITORIO e DTA_SOLICITACAO_REC_FINANC nulos:' || CHR(10) || CHR(10) ||
                       'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2326,2327,2328,2329) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and DTA_OFICIO_REQUISITORIO is NULL and DTA_SOLICITACAO_REC_FINANC is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios: COD_ENTE_PUBLICO, NUM_VALOR_ATUALIZADO, DTA_SOLICITACAO_REC_FINANC */

  dbms_output.put_line('Processos com o atributo COD_ENTE_PUBLICO nulo:' || CHR(10) || CHR(10) ||
                     'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, NUM_RAMO_ATIVIDADE, proc.NR_PROCESSO_ATUAL 
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2345,2346,2347,2348) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and COD_ENTE_PUBLICO is NULL) 
       LOOP
       IF(resultado.NUM_RAMO_ATIVIDADE in (1201,1202,1203)) -- Verifica se  um ente pblico
       THEN dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END IF;
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));


   dbms_output.put_line('Processos com o atributo NUM_VALOR_ATUALIZADO nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2345,2346,2347,2348) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and NUM_VALOR_ATUALIZADO is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

 dbms_output.put_line('Processos com o atributo DTA_SOLICITACAO_REC_FINANC nulo:' || CHR(10) || CHR(10) ||
                       'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2345,2346,2347,2348) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote
                     and DTA_SOLICITACAO_REC_FINANC is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios: NUM_UNIDADE  */

   dbms_output.put_line('Processos com o atributo NUM_UNIDADE nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2120,2307,2308) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote 
                     and NUM_UNIDADE is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));
       
-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios: NUM_CLASSE  */

   dbms_output.put_line('Processos com o atributo NUM_CLASSE nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2121) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote 
                     and NUM_CLASSE is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));
       
-----------------------------------------------------------------------------------------------
/* Verificao dos campos obrigatrios:  NUM_CLASSE_ANTERIOR */

   dbms_output.put_line('Processos com o atributo NUM_CLASSE_ANTERIOR nulo:' || CHR(10) || CHR(10) ||
                        'NUM_INTERNO_PROCESSO  NUM_ITEM  NR_PROCESSO_ATUAL');

   FOR resultado IN (select NUM_INTERNO_PROCESSO, NUM_ITEM, proc.NR_PROCESSO_ATUAL
                     from egt_info_processo p, sap.tb_processo proc
                     where p.NUM_INTERNO_PROCESSO = proc.SQ_PROCESSO
                     and NUM_ITEM in (2222) 
                     and NUM_REMESSA = remessa and NUM_LOTE = lote 
                     and NUM_CLASSE_ANTERIOR is NULL) 
       LOOP
       dbms_output.put_line(resultado.NUM_INTERNO_PROCESSO || '               ' || resultado.NUM_ITEM || '      ' || resultado.NR_PROCESSO_ATUAL);
       END LOOP;
       dbms_output.put_line('--------------------  --------'|| CHR(10) || CHR(10));

END;

